@@ -3,6 +3,8 @@ Angel OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/angel.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -25,7 +27,7 @@ class AngelOAuth2(BaseOAuth2):
             "email": email,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://api.angel.co/1/me/", params={"access_token": access_token}
