@@ -14,7 +14,7 @@ class AsanaOAuth2(BaseOAuth2):
     REDIRECT_STATE = False
     USER_DATA_URL = "https://app.asana.com/api/1.0/users/me"
     EXTRA_DATA = [
-        ("expires_in", "expires"),
+        ("expires_in", "expires_in"),
         ("refresh_token", "refresh_token"),
         ("name", "name"),
     ]
@@ -30,7 +30,7 @@ class AsanaOAuth2(BaseOAuth2):
             "first_name": first_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         return self.get_json(
             self.USER_DATA_URL, headers={"Authorization": f"Bearer {access_token}"}
         )
