@@ -51,7 +51,7 @@ class AzureADOAuth2(BaseOAuth2):
         ("access_token", "access_token"),
         ("id_token", "id_token"),
         ("refresh_token", "refresh_token"),
-        ("expires_in", "expires"),
+        ("expires_in", "expires_in"),
         ("expires_on", "expires_on"),
         ("not_before", "not_before"),
         ("given_name", "first_name"),
@@ -101,7 +101,7 @@ class AzureADOAuth2(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         response = kwargs.get("response")
         if response and response.get("id_token"):
             id_token = response.get("id_token")
