@@ -2,6 +2,8 @@
 Bungie OAuth2 backend
 """
 
+from typing import Any
+
 from social_core.backends.oauth import BaseOAuth2
 
 
@@ -15,7 +17,7 @@ class BungieOAuth2(BaseOAuth2):
     EXTRA_DATA = [
         ("refresh_token", "refresh_token", True),
         ("access_token", "access_token", True),
-        ("expires_in", "expires"),
+        ("expires_in", "expires_in"),
         ("membership_id", "membership_id"),
         ("refresh_expires_in", "refresh_expires_in"),
     ]
@@ -61,7 +63,7 @@ class BungieOAuth2(BaseOAuth2):
         kwargs.update({"response": response, "backend": self})
         return self.strategy.authenticate(*args, **kwargs)
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Grab user profile information from Bunige"""
         membership_id = kwargs["response"]["membership_id"]
         url = "https://www.bungie.net/Platform/User/GetBungieNetUser/"
