@@ -1,3 +1,5 @@
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -32,10 +34,10 @@ class DigitalOceanOAuth(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         url = "https://api.digitalocean.com/v2/account"
-        auth_header = {"Authorization": f"Bearer {token}"}
+        auth_header = {"Authorization": f"Bearer {access_token}"}
         try:
             return self.get_json(url, headers=auth_header)
         except ValueError:
