@@ -3,6 +3,8 @@ Dropbox OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/dropbox.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -24,7 +26,7 @@ class DropboxOAuth2V2(BaseOAuth2):
             "last_name": name.get("surname"),
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://api.dropboxapi.com/2/users/get_current_account",
