@@ -3,6 +3,8 @@ Edmodo OAuth2 Sign-in backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/edmodo.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -26,7 +28,7 @@ class EdmodoOAuth2(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from Edmodo"""
         return self.get_json(
             "https://api.edmodo.com/users/me", params={"access_token": access_token}
