@@ -3,7 +3,7 @@ Fitbit OAuth backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/fitbit.html
 """
 
-import base64
+from typing import Any
 
 from .oauth import BaseOAuth1, BaseOAuth2
 
@@ -22,7 +22,7 @@ class FitbitOAuth1(BaseOAuth1):
         """Return user details from Fitbit account"""
         return {"username": response.get("displayName"), "email": ""}
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: dict, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://api.fitbit.com/1/user/-/profile.json",
@@ -41,7 +41,7 @@ class FitbitOAuth2(BaseOAuth2):
     ID_KEY = "encodedId"
     REDIRECT_STATE = False
     EXTRA_DATA = [
-        ("expires_in", "expires"),
+        ("expires_in", "expires_in"),
         ("refresh_token", "refresh_token", True),
         ("encodedId", "id"),
         ("displayName", "username"),
@@ -51,7 +51,7 @@ class FitbitOAuth2(BaseOAuth2):
         """Return user details from Fitbit account"""
         return {"username": response.get("displayName"), "email": ""}
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         auth_header = {"Authorization": f"Bearer {access_token}"}
         return self.get_json(
@@ -59,7 +59,4 @@ class FitbitOAuth2(BaseOAuth2):
         )["user"]
 
     def auth_headers(self):
-        tokens = "{}:{}".format(*self.get_key_and_secret())
-        tokens = base64.urlsafe_b64encode(tokens.encode())
-        tokens = tokens.decode()
-        return {"Authorization": f"Basic {tokens}"}
+        return {"Authorization": self.get_key_and_secret_basic_auth()}
