@@ -3,6 +3,8 @@ Flat OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/flat.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -25,7 +27,7 @@ class FlatOAuth2(BaseOAuth2):
             "fullname": response.get("printableName"),
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://api.flat.io/v2/me",
