@@ -3,6 +3,8 @@ Foursquare OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/foursquare.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -30,7 +32,7 @@ class FoursquareOAuth2(BaseOAuth2):
             "email": email,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://api.foursquare.com/v2/users/self",
