@@ -5,7 +5,8 @@ Github Enterprise OAuth2 backend, docs at:
 
 from urllib.parse import urljoin
 
-from ..utils import append_slash
+from social_core.utils import append_slash
+
 from .github import GithubOAuth2, GithubOrganizationOAuth2, GithubTeamOAuth2
 
 
