@@ -1,3 +1,5 @@
+from typing import Any
+
 from .goclio import GoClioOAuth2
 
 
@@ -6,7 +8,7 @@ class GoClioEuOAuth2(GoClioOAuth2):
     AUTHORIZATION_URL = "https://app.goclio.eu/oauth/authorize/"
     ACCESS_TOKEN_URL = "https://app.goclio.eu/oauth/token/"
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://app.goclio.eu/api/v2/users/who_am_i",
