@@ -1,3 +1,5 @@
+from typing import Any
+
 from social_core.backends.oauth import BaseOAuth2
 
 
@@ -20,7 +22,7 @@ class GrafanaOAuth2(BaseOAuth2):
             "last_name": "-",
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             self.USER_DETAILS_URL,
