@@ -3,6 +3,8 @@ Instagram OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/instagram.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -29,7 +31,7 @@ class InstagramOAuth2(BaseOAuth2):
             "email": email,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         # For more fields see:
         # https://developers.facebook.com/docs/instagram-basic-display-api/reference/user#fields
