@@ -3,6 +3,8 @@ Kakao OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/kakao.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -37,7 +39,7 @@ class KakaoOAuth2(BaseOAuth2):
             "last_name": nickname[0] if nickname else "",
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://kapi.kakao.com/v2/user/me",
