@@ -62,7 +62,7 @@ class LoginRadiusAuth(BaseOAuth2):
             },
         )
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service. Implement in subclass."""
         return self.get_json(
             self.PROFILE_URL,
@@ -92,4 +92,4 @@ class LoginRadiusAuth(BaseOAuth2):
         """Return a unique ID for the current user, by default from server
         response. Since LoginRadius handles multiple providers, we need to
         distinguish them to prevent conflicts."""
-        return "{}-{}".format(response.get("Provider"), response.get(self.ID_KEY))
+        return "{}-{}".format(response.get("Provider"), response.get(self.id_key()))
