@@ -6,6 +6,7 @@ from typing import TYPE_CHECKING, Any, Literal, cast
 from urllib.parse import urlencode
 
 from oauthlib.oauth1 import SIGNATURE_TYPE_AUTH_HEADER
+from requests.auth import AuthBase
 from requests_oauthlib import OAuth1
 
 from social_core.exceptions import (
@@ -144,7 +145,7 @@ class OAuthAuth(BaseAuth):
 
     def user_data(self, access_token, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service. Implement in subclass"""
-        return {}
+        raise NotImplementedError
 
     def authorization_url(self) -> str:
         url = self.setting("AUTHORIZATION_URL", self.AUTHORIZATION_URL)
@@ -353,6 +354,10 @@ class BaseOAuth1(OAuthAuth):
             method=self.ACCESS_TOKEN_METHOD,
         )
 
+    def user_data(self, access_token: dict, *args, **kwargs) -> dict[str, Any] | None:
+        """Loads user data from service. Implement in subclass"""
+        return {}
+
 
 class BaseOAuth2(OAuthAuth):
     """Base class for OAuth2 providers.
@@ -493,7 +498,7 @@ class BaseOAuth2(OAuthAuth):
         kwargs.update({"response": response, "backend": self})
         return self.strategy.authenticate(*args, **kwargs)
 
-    def refresh_token_params(self, token, *args, **kwargs):
+    def refresh_token_params(self, token: str, *args, **kwargs) -> dict[str, str]:
         client_id, client_secret = self.get_key_and_secret()
         return {
             "refresh_token": token,
@@ -502,21 +507,34 @@ class BaseOAuth2(OAuthAuth):
             "client_secret": client_secret,
         }
 
-    def process_refresh_token_response(self, response, *args, **kwargs):
+    def refresh_token_auth(self) -> AuthBase | None:
+        return None
+
+    def process_refresh_token_response(self, response, *args, **kwargs) -> dict:
         return response.json()
 
-    def refresh_token(self, token, *args, **kwargs):
+    def refresh_token(self, token: str, *args, **kwargs) -> dict:
         params = self.refresh_token_params(token, *args, **kwargs)
         url = self.refresh_token_url()
         method = self.REFRESH_TOKEN_METHOD
-        key = "params" if method == "GET" else "data"
-        request_args = {"headers": self.auth_headers(), "method": method, key: params}
-        request = self.request(url, **request_args)
+        is_get = method == "GET"
+        request = self.request(
+            url,
+            headers=self.auth_headers(),
+            method=method,
+            auth=self.refresh_token_auth(),
+            data=params if not is_get else None,
+            params=params if is_get else None,
+        )
         return self.process_refresh_token_response(request, *args, **kwargs)
 
     def refresh_token_url(self):
         return self.REFRESH_TOKEN_URL or self.access_token_url()
 
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
+        """Loads user data from service. Implement in subclass"""
+        return {}
+
 
 class BaseOAuth2PKCE(BaseOAuth2):
     """
