@@ -3,6 +3,8 @@ ORCID OAuth2 Application backend, docs at:
 https://python-social-auth.readthedocs.io/en/latest/backends/orcid.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -18,7 +20,7 @@ class ORCIDOAuth2(BaseOAuth2):
     DEFAULT_SCOPE = ["/authenticate"]
     EXTRA_DATA = [
         ("orcid", "id"),
-        ("expires_in", "expires"),
+        ("expires_in", "expires_in"),
         ("refresh_token", "refresh_token"),
     ]
 
@@ -99,7 +101,7 @@ class ORCIDOAuth2(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         params = self.setting("PROFILE_EXTRA_PARAMS", {})
         params["access_token"] = access_token
