@@ -3,6 +3,8 @@ SimpleLogin OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/simplelogin.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -34,6 +36,6 @@ class SimpleLoginOAuth2(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(self.USERINFO_URL, params={"access_token": access_token})
