@@ -3,6 +3,8 @@ Stripe OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/stripe.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -23,7 +25,7 @@ class StripeOAuth2(BaseOAuth2):
         ("stripe_user_id", "stripe_user_id"),
     ]
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Grab user profile information from Stripe"""
         return self.get_json(
             "https://api.stripe.com/v1/account",
@@ -57,5 +59,5 @@ class StripeOAuth2(BaseOAuth2):
             "Authorization": f"Bearer {client_secret}",
         }
 
-    def refresh_token_params(self, refresh_token, *args, **kwargs):
-        return {"refresh_token": refresh_token, "grant_type": "refresh_token"}
+    def refresh_token_params(self, token: str, *args, **kwargs) -> dict[str, str]:
+        return {"refresh_token": token, "grant_type": "refresh_token"}
