@@ -3,6 +3,8 @@ SurveyMonkey OAuth2 backend, docs at:
     https://developer.surveymonkey.com/api/v3/#authentication
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -24,7 +26,7 @@ class SurveyMonkeyOAuth2(BaseOAuth2):
         response["name"] = response["first_name"] + " " + response["last_name"]
         return response
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data information from service"""
         base_url = kwargs["response"]["access_url"]
         return self.get_json(
