@@ -3,6 +3,8 @@ Uber OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/uber.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -30,7 +32,7 @@ class UberOAuth2(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         response = kwargs.pop("response")
         return self.get_json(
