@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import cast
+from typing import Any, cast
 
 from .oauth import BaseOAuth1, BaseOAuth2
 
@@ -30,7 +30,7 @@ class VimeoOAuth1(BaseOAuth1):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: dict, *args, **kwargs) -> dict[str, Any] | None:
         """Return user data provided"""
         return self.get_json(
             "https://vimeo.com/api/rest/v2",
@@ -77,7 +77,7 @@ class VimeoOAuth2(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Return user data provided"""
         return self.get_json(
             "https://api.vimeo.com/me",
