@@ -4,6 +4,8 @@ Weibo OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/weibo.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -50,11 +52,13 @@ class WeiboOAuth2(BaseOAuth2):
         )
         return data["uid"]
 
-    def user_data(self, access_token, response=None, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Return user data"""
         # If user id was not retrieved in the response, then get it directly
         # from weibo get_token_info endpoint
-        uid = (response and response.get("uid")) or self.get_uid(access_token)
+        uid = ("response" in kwargs and kwargs["response"].get("uid")) or self.get_uid(
+            access_token
+        )
         user_data = self.get_json(
             "https://api.weibo.com/2/users/show.json",
             params={"access_token": access_token, "uid": uid},
