@@ -1,9 +1,17 @@
-from ..exceptions import InvalidEmail
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
+from social_core.exceptions import InvalidEmail
+
 from .partial import partial
 
+if TYPE_CHECKING:
+    from social_core.backends.base import BaseAuth
+
 
 @partial
-def mail_validation(backend, details, is_new=False, *args, **kwargs):
+def mail_validation(backend: BaseAuth, details, is_new=False, *args, **kwargs):
     requires_validation = backend.REQUIRES_EMAIL_VALIDATION or backend.setting(
         "FORCE_EMAIL_VALIDATION", False
     )
@@ -19,7 +27,7 @@ def mail_validation(backend, details, is_new=False, *args, **kwargs):
             ):
                 raise InvalidEmail(backend)
             return None
-        current_partial = kwargs.get("current_partial")
+        current_partial = kwargs["current_partial"]
         backend.strategy.send_email_validation(
             backend, details["email"], current_partial.token
         )
