@@ -1,10 +1,10 @@
 from __future__ import annotations
 
 import secrets
-from typing import TYPE_CHECKING, Any, cast
+from typing import TYPE_CHECKING, Any, Protocol, cast
 
 from .backends.utils import get_backend
-from .exceptions import StrategyMissingFeatureError
+from .exceptions import StrategyMissingBackendError, StrategyMissingFeatureError
 from .pipeline import DEFAULT_AUTH_PIPELINE, DEFAULT_DISCONNECT_PIPELINE
 from .pipeline.utils import partial_load
 from .store import OpenIdSessionWrapper, OpenIdStore
@@ -12,7 +12,11 @@ from .utils import PARTIAL_TOKEN_SESSION_NAME, module_member, setting_name
 
 if TYPE_CHECKING:
     from .backends.base import BaseAuth
-    from .storage import BaseStorage, CodeMixin
+    from .storage import BaseStorage, CodeMixin, PartialMixin, UserProtocol
+
+
+class HttpResponseProtocol(Protocol):
+    url: str
 
 
 class BaseTemplateStrategy:
@@ -45,7 +49,9 @@ class BaseStrategy:
     SESSION_SAVE_KEY = "psa_session_id"
 
     def __init__(
-        self, storage: type[BaseStorage], tpl: type[BaseTemplateStrategy] | None = None
+        self,
+        storage: type[BaseStorage] | None = None,
+        tpl: type[BaseTemplateStrategy] | None = None,
     ) -> None:
         self.storage = storage
         self.tpl = (tpl or self.DEFAULT_TEMPLATE_STRATEGY)(self)
@@ -62,12 +68,16 @@ class BaseStrategy:
         return default
 
     def create_user(self, *args, **kwargs):
+        if self.storage is None:
+            raise StrategyMissingBackendError
         return self.storage.user.create_user(*args, **kwargs)
 
     def get_user(self, *args, **kwargs):
+        if self.storage is None:
+            raise StrategyMissingBackendError
         return self.storage.user.get_user(*args, **kwargs)
 
-    def session_setdefault(self, name, value):
+    def session_setdefault(self, name: str, value):
         self.session_set(name, value)
         return self.session_get(name)
 
@@ -85,7 +95,7 @@ class BaseStrategy:
         """
         raise StrategyMissingFeatureError(self.__class__.__name__, "session restore")
 
-    def openid_session_dict(self, name):
+    def openid_session_dict(self, name: str) -> OpenIdSessionWrapper:
         # Many frameworks are switching the session serialization from Pickle
         # to JSON to avoid code execution risks. Flask did this from Flask
         # 0.10, Django is switching to JSON by default from version 1.6.
@@ -107,16 +117,18 @@ class BaseStrategy:
     def from_session_value(self, val):
         return val
 
-    def partial_load(self, token):
+    def partial_load(self, token: str) -> PartialMixin | None:
         return partial_load(self, token)
 
     def clean_partial_pipeline(self, token) -> None:
+        if self.storage is None:
+            raise StrategyMissingBackendError
         self.storage.partial.destroy(token)
         current_token_in_session = self.session_get(PARTIAL_TOKEN_SESSION_NAME)
         if current_token_in_session == token:
             self.session_pop(PARTIAL_TOKEN_SESSION_NAME)
 
-    def openid_store(self):
+    def openid_store(self) -> OpenIdStore:
         return OpenIdStore(self)
 
     def get_pipeline(self, backend: BaseAuth | None = None) -> list[str]:
@@ -133,7 +145,7 @@ class BaseStrategy:
     def random_string(self, length: int = 12, chars: str = ALLOWED_CHARS) -> str:
         return "".join([secrets.choice(chars) for i in range(length)])
 
-    def absolute_uri(self, path=None):
+    def absolute_uri(self, path: str | None = None) -> str | None:
         uri = self.build_absolute_uri(path)
         if uri and self.setting("REDIRECT_IS_HTTPS"):
             uri = uri.replace("http://", "https://")
@@ -146,6 +158,8 @@ class BaseStrategy:
     def send_email_validation(
         self, backend: BaseAuth, email: str, partial_token: str | None = None
     ) -> CodeMixin:
+        if self.storage is None:
+            raise StrategyMissingBackendError
         email_validation = self.setting("EMAIL_VALIDATION_FUNCTION")
         send_email = module_member(email_validation)
         code = self.storage.code.make_code(email)
@@ -153,6 +167,8 @@ class BaseStrategy:
         return code
 
     def validate_email(self, email: str, code: str) -> bool:
+        if self.storage is None:
+            raise StrategyMissingBackendError
         verification_code = self.storage.code.get_code(code)
         if not verification_code or verification_code.code != code:
             return False
@@ -172,9 +188,13 @@ class BaseStrategy:
         """Render given template or raw html with given context"""
         return self.tpl.render(tpl, html, context)
 
-    def authenticate(self, backend: BaseAuth, *args, **kwargs):
+    def authenticate(
+        self, backend: BaseAuth, *args, **kwargs
+    ) -> UserProtocol | HttpResponseProtocol | None:
         """Trigger the authentication mechanism tied to the current
         framework"""
+        if self.storage is None:
+            raise StrategyMissingBackendError
         kwargs["strategy"] = self
         kwargs["storage"] = self.storage
         kwargs["backend"] = backend
@@ -195,27 +215,28 @@ class BaseStrategy:
         return get_backend(self.get_backends(), name)
 
     def get_backend(
-        self, name: str, redirect_uri: str | None = None, *args, **kwargs
+        self, name: str, redirect_uri: str | None = None, **kwargs
     ) -> BaseAuth:
         """Return a configured backend instance"""
-        Backend = self.get_backend_class(name)
-        return Backend(self, *args, redirect_uri=redirect_uri, **kwargs)
+        backend_class = self.get_backend_class(name)
+        kwargs["redirect_uri"] = redirect_uri
+        return backend_class(self, **kwargs)
 
     # Implement the following methods on strategies sub-classes
 
-    def redirect(self, url):
+    def redirect(self, url: str) -> HttpResponseProtocol:
         """Return a response redirect to the given URL"""
         raise NotImplementedError("Implement in subclass")
 
-    def get_setting(self, name):
+    def get_setting(self, name: str):
         """Return value for given setting name"""
         raise NotImplementedError("Implement in subclass")
 
-    def html(self, content):
+    def html(self, content: str) -> HttpResponseProtocol:
         """Return HTTP response with given content"""
         raise NotImplementedError("Implement in subclass")
 
-    def request_data(self, merge=True):
+    def request_data(self, merge: bool = True):
         """Return current request data (POST or GET)"""
         raise NotImplementedError("Implement in subclass")
 
@@ -223,19 +244,19 @@ class BaseStrategy:
         """Return current host value"""
         raise NotImplementedError("Implement in subclass")
 
-    def session_get(self, name, default=None):
+    def session_get(self, name: str, default=None):
         """Return session value for given key"""
         raise NotImplementedError("Implement in subclass")
 
-    def session_set(self, name, value):
+    def session_set(self, name: str, value):
         """Set session value for given key"""
         raise NotImplementedError("Implement in subclass")
 
-    def session_pop(self, name):
+    def session_pop(self, name: str):
         """Pop session value for given key"""
         raise NotImplementedError("Implement in subclass")
 
-    def build_absolute_uri(self, path: str | None = None) -> str:
+    def build_absolute_uri(self, path: str | None = None) -> str | None:
         """Build absolute URI with given (optional) path"""
         raise NotImplementedError("Implement in subclass")
 
