@@ -1,7 +1,10 @@
+from __future__ import annotations
+
 import requests
 import responses
 
-from ...utils import parse_qs
+from social_core.utils import parse_qs
+
 from .base import BaseBackendTest
 
 
@@ -9,7 +12,7 @@ class BaseLegacyTest(BaseBackendTest):
     form = ""
     response_body = ""
 
-    def setUp(self):
+    def setUp(self) -> None:
         super().setUp()
         self.strategy.set_settings(
             {
@@ -19,7 +22,7 @@ class BaseLegacyTest(BaseBackendTest):
             }
         )
 
-    def extra_settings(self):
+    def extra_settings(self) -> dict[str, str | list[str]]:
         return {f"SOCIAL_AUTH_{self.name}_FORM_URL": f"/login/{self.backend.name}"}
 
     def do_start(self):
