@@ -31,8 +31,8 @@ class AngelOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
     )
     expected_username = "foobar"
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
