@@ -70,8 +70,8 @@ class Auth0OAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
         )
         return super().auth_handlers(start_url)
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
