@@ -58,18 +58,18 @@ class BoxOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
         }
     )
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
 
     def refresh_token_arguments(self):
         uri = self.strategy.build_absolute_uri("/complete/box/")
         return {"redirect_uri": uri}
 
-    def test_refresh_token(self):
-        user, social = self.do_refresh_token()
+    def test_refresh_token(self) -> None:
+        _user, social = self.do_refresh_token()
         self.assertEqual(
             social.extra_data["access_token"], "T9cE5asGnuyYCCqIZFoWjFHvNbvVqHjl"
         )
