@@ -12,8 +12,8 @@ class EmailTest(BaseLegacyTest):
     </form>
     """
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
