@@ -47,10 +47,10 @@ class GitLabOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
         }
     )
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
 
 
@@ -98,13 +98,13 @@ class GitLabCustomDomainOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
         }
     )
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.strategy.set_settings(
             {"SOCIAL_AUTH_GITLAB_API_URL": "https://example.com"}
         )
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.strategy.set_settings(
             {"SOCIAL_AUTH_GITLAB_API_URL": "https://example.com"}
         )
