@@ -19,8 +19,8 @@ class InstagramOAuth2Test(OAuth2Test, BaseAuthUrlTestMixin):
         {"meta": {"code": 200}, "username": "foobar", "id": "101010101"}
     )
 
-    def test_login(self):
+    def test_login(self) -> None:
         self.do_login()
 
-    def test_partial_pipeline(self):
+    def test_partial_pipeline(self) -> None:
         self.do_partial_pipeline()
