@@ -24,7 +24,9 @@ from .exceptions import (
 )
 
 if TYPE_CHECKING:
-    from social_core.backends.base import BaseAuth
+    from .backends.base import BaseAuth
+    from .storage import UserProtocol
+    from .strategy import BaseStrategy
 
 SETTING_PREFIX = "SOCIAL_AUTH"
 
@@ -61,7 +63,7 @@ def url_add_parameters(
         fragments[4] = urlencode(value)
         if _unquote_query:
             fragments[4] = unquote(fragments[4])
-        url = urlunparse(fragments)  # ty: ignore[invalid-assignment]
+        url = urlunparse(fragments)
     return url
 
 
@@ -98,7 +100,7 @@ def sanitize_redirect(hosts, redirect_to):
             return redirect_to
 
 
-def user_is_authenticated(user):
+def user_is_authenticated(user: UserProtocol | None) -> bool:
     if user and hasattr(user, "is_authenticated"):
         if callable(user.is_authenticated):
             authenticated = user.is_authenticated()
@@ -111,7 +113,7 @@ def user_is_authenticated(user):
     return authenticated
 
 
-def user_is_active(user):
+def user_is_active(user: UserProtocol | None) -> bool:
     if user and hasattr(user, "is_active"):
         is_active = user.is_active() if callable(user.is_active) else user.is_active
     elif user:
@@ -186,9 +188,10 @@ def partial_pipeline_data(backend, user=None, partial_token=None, *args, **kwarg
             # Normally when resuming a pipeline, request_data will be empty. We
             # only need to check for a uid match if new data was provided (i.e.
             # if current request specifies the ID_KEY).
-            if backend.ID_KEY and backend.ID_KEY in request_data:
+            id_key = backend.id_key()
+            if id_key and id_key in request_data:
                 id_from_partial = partial.kwargs.get("uid")
-                id_from_request = request_data.get(backend.ID_KEY)
+                id_from_request = request_data.get(id_key)
 
                 if id_from_partial != id_from_request:
                     partial_matches_request = False
@@ -204,7 +207,7 @@ def partial_pipeline_data(backend, user=None, partial_token=None, *args, **kwarg
     return None
 
 
-def build_absolute_uri(host_url, path=None):
+def build_absolute_uri(host_url: str, path: str | None = None) -> str:
     """Build absolute URI with given (optional) path"""
     path = path or ""
     if path.startswith(("http://", "https://")):
@@ -214,7 +217,7 @@ def build_absolute_uri(host_url, path=None):
     return host_url + path
 
 
-def constant_time_compare(val1, val2):
+def constant_time_compare(val1: str | bytes, val2: str | bytes) -> bool:
     """Compare two values and prevent timing attacks for cryptographic use."""
     if isinstance(val1, str):
         val1 = val1.encode("utf-8")
@@ -223,12 +226,15 @@ def constant_time_compare(val1, val2):
     return hmac.compare_digest(val1, val2)
 
 
-def is_url(value):
-    return value and (value.startswith(("http://", "https://", "/")))
+def is_url(value: str | None) -> bool:
+    return value is not None and value.startswith(("http://", "https://", "/"))
 
 
-def setting_url(backend, *names):
+def setting_url(backend: BaseAuth, *names: str | None) -> str | None:
     for name in names:
+        # Name can actually None, value or setting name
+        if not name:
+            continue
         if is_url(name):
             return name
         value = backend.setting(name)
@@ -270,7 +276,7 @@ def wrap_access_token_error(backend: BaseAuth):
         raise
 
 
-def append_slash(url):
+def append_slash(url: str) -> str:
     """Make sure we append a slash at the end of the URL otherwise we
     have issues with urljoin Example:
     >>> urlparse.urljoin('http://www.example.com/api/v3', 'user/1/')
@@ -281,7 +287,7 @@ def append_slash(url):
     return url
 
 
-def get_strategy(strategy, storage, *args, **kwargs):
+def get_strategy(strategy: str, storage: str, *args, **kwargs) -> BaseStrategy:
     Strategy = module_member(strategy)
     Storage = module_member(storage)
     return Strategy(Storage, *args, **kwargs)
